@@ -25,27 +25,15 @@ class ArcInfo(pw.Model):
         primary_key = pw.CompositeKey("arcaea_name", "arcaea_id", "ptt")
 
 
-class UserConfig(pw.Model):
-    user_qq = pw.IntegerField()
-    single_song_theme = pw.CharField()
-    best30_theme = pw.CharField()
-
-    class Meta:
-        database = db
-        primary_key = pw.CompositeKey("user_qq", "single_song_theme", "best30_theme")
-
-
 if not path.exists(db_root / "user_data.db"):
     logger.info(f"创建数据库于 {db_root / 'user_data.db'}")
     db.connect()
-    db.create_tables([UserInfo, ArcInfo, UserConfig])
+    db.create_tables([UserInfo, ArcInfo])
     db.close()
 else:
     db.connect()
     if "userinfo" not in db.get_tables():
         db.create_tables([UserInfo])
-    if "userconfig" not in db.get_tables():
-        db.create_tables([UserConfig])
     if "arcinfo" not in db.get_tables():
         db.create_tables([ArcInfo])
     db.close()
